@@ -72,7 +72,9 @@ def convert(args, match):
         lib = loader.load(match)
         if not args.no_patches:
             patcher.apply_all(lib)
-        converter.convert(lib, args.format, args.output)
+        converter.convert(
+            lib, fmt=args.format, output=args.output, relative=args.relative_source
+        )
         return True
     except ImportError:
         debug_traceback()
@@ -121,12 +123,16 @@ def create_parser():
         help="Don't parse resources from current directory",
     )
     parser.add_argument(
-        "--template",
-        help="HTML template for library documentation page"
+        "--template", help="HTML template for library documentation page"
     )
     parser.add_argument(
         "-v", "--verbose", help="be more talkative", action="store_true"
     )
+    parser.add_argument(
+        "--relative-source",
+        action="store_true",
+        help="Set keyword source as a relative directory",
+    )
     return parser
 
 
